"use strict";
exports.__esModule = true;
var tslib_1 = require("tslib");
var lib_date_1 = require("./lib_date");
var EduRequest = (function () {
    function EduRequest() {
        this.props = null;
        this.edupage = '';
        this.lang = '';
        this.firstDayOfWeek = 1;
        this.weekendDays = [];
        this.school_country = '';
        this.school_state = '';
        this.schoolyear_turnover = '';
        this.custom_turnover = {};
        this.loggedUser = '';
        this.loggedUserRights = [];
        this.sort_name_col = 'FSL';
        this.edupageLangs = null;
        this.ttlangasc = null;
        this._memoize_cache = new Map();
    }
    EduRequest.prototype.initRequest = function (props) {
        this.props = props;
        for (var _i = 0, _a = [
            'edupage',
            'lang',
            'firstDayOfWeek',
            'weekendDays',
            'school_country',
            'school_state',
            'schoolyear_turnover',
            'custom_turnover',
            'loggedUser',
            'loggedUserRights',
            'parent_studentid',
            'sort_name_col',
            'jsmodulemode',
        ]; _i < _a.length; _i++) {
            var c = _a[_i];
            var v = props[c];
            if (v !== undefined)
                this[c] = v;
        }
    };
    EduRequest.prototype.getSchoolYear = function (date) {
        if (date === void 0) { date = this.timezone_date(); }
        if (!date || !this.schoolyear_turnover)
            ASC.dieError('8130146806');
        var year = parseInt(date.substr(0, 4));
        if (date < this.schoolYear_turnOver(year))
            year--;
        return year;
    };
    EduRequest.prototype.getSchoolYearName = function (year) {
        if (!year)
            return '';
        if (this.schoolYear_turnOver(year + 1) <= (year + 1) + '-02-01')
            return '' + year;
        else
            return year + '/' + (year + 1);
    };
    EduRequest.prototype.schoolYear_turnOver = function (year) {
        return this.custom_turnover[year] || (year + '-' + this.schoolyear_turnover);
    };
    EduRequest.prototype.schoolYear_turnOver_end = function (year) {
        return lib_date_1.date_delta(this.schoolYear_turnOver(year + 1), -1);
    };
    EduRequest.prototype.isAdmin = function () {
        return this.loggedUser == 'Admin';
    };
    EduRequest.prototype.isUcitel = function () {
        if (this.loggedUser.substr(0, 6) == 'Ucitel')
            return this.loggedUser.substr(6);
        return '';
    };
    EduRequest.prototype.isStudent = function () {
        if (this.loggedUser.substr(0, 7) == 'Student')
            return this.loggedUser.substr(7);
        return '';
    };
    EduRequest.prototype.isStudentOrParent = function () {
        return this.isStudent() || this.props.parent_studentid || '';
    };
    EduRequest.prototype.isParent = function () {
        if (this.loggedUser.substr(0, 5) == 'Rodic')
            return this.loggedUser.substr(5);
        return '';
    };
    EduRequest.prototype.isGuest = function () {
        if (this.loggedUser.substr(0, 5) == 'Guest')
            return this.loggedUser.substr(5);
        return '';
    };
    EduRequest.prototype.isAscAdmin = function () {
        return !!this.props.ascadmin;
    };
    EduRequest.prototype.isAscDebug = function () {
        return !!this.props.ascdebug;
    };
    EduRequest.prototype.isAscDevelop = function () {
        return !!this.props.ascdevelop;
    };
    EduRequest.prototype.isApp = function () {
        return !!this.props.app;
    };
    EduRequest.prototype.hasRight = function (right) {
        if (this.isAdmin()) {
            return !['limited'].includes(right);
        }
        return this.loggedUserRights.includes(right);
    };
    EduRequest.prototype.jeZUS = function () {
        return !!this.props.jeZUS;
    };
    EduRequest.prototype.isAgenda = function () {
        return !!this.props.isAgenda;
    };
    EduRequest.prototype.uiError = function (errNumber, msg, info) {
        if (typeof msg !== 'string')
            ASC.dieError('8358216710');
        console.error('Error', errNumber);
        if (msg)
            console.log(msg);
        if (info !== undefined)
            console.log(info);
        var e = new Error('' + errNumber);
        e['errNumber'] = errNumber;
        e['msg'] = msg;
        throw e;
    };
    EduRequest.prototype.ls = function (i) {
        if (this.edupageLangs && this.edupageLangs[i]) {
            return this.edupageLangs[i];
        }
        return ASC.ls(i);
    };
    EduRequest.prototype.lsf = function (i, replace) {
        if (this.edupageLangs && this.edupageLangs[i]) {
            i = this.edupageLangs[i];
        }
        return ASC.lsf(i, replace);
    };
    EduRequest.prototype.ttls = function (i) {
        if (this.ttlangasc && this.ttlangasc[i]) {
            return this.ttlangasc[i];
        }
        return ASC.ttls(i);
    };
    EduRequest.prototype.ttlsf = function (i, replace) {
        var s = this.ttls(i);
        for (var k in replace) {
            s = s.replace('%' + k, replace[k]);
        }
        return s;
    };
    EduRequest.prototype.uls = function (i, lf) {
        switch (lf) {
            case 'tt': return this.ttls(i);
        }
        return this.ls(i);
    };
    EduRequest.prototype.localize = function (s) {
        for (var i = 0; i < 10; i++) {
            var m = /\{(?:|([a-z]{2}):)([0-9]{4,5})\}/g.exec(s);
            if (!m)
                break;
            s = s.replace(m[0], this.uls(parseInt(m[2]), m[1]));
        }
        return s;
    };
    EduRequest.prototype.timezone_date = function (time) {
        if (time === void 0) { time = undefined; }
        return this.timezone_datetime(time).substr(0, 10);
    };
    EduRequest.prototype.timezone_datetime = function (time) {
        if (time === void 0) { time = undefined; }
        var d = typeof time == 'number' ? new Date(time * 1000) : new Date();
        var parts;
        try {
            var df = new Intl.DateTimeFormat('en-US', {
                year: 'numeric',
                month: 'numeric',
                day: 'numeric',
                hour: 'numeric',
                minute: 'numeric',
                second: 'numeric',
                hour12: false,
                timeZone: this.props.timezone
            });
            var s = df.format(d);
            parts = /(\d+)\D+(\d+)\D+(\d+)\D+(\d+)\D+(\d+)\D+(\d+)/.exec(s);
        }
        catch (e) {
            parts = [
                0,
                d.getMonth() + 1,
                d.getDate(),
                d.getFullYear(),
                d.getHours(),
                d.getMinutes(),
                d.getSeconds()
            ];
        }
        function zpl(i, len) {
            var s = '' + parts[i];
            while (s.length < len)
                s = '0' + s;
            return s;
        }
        return zpl(3, 4) + '-'
            + zpl(1, 2) + '-'
            + zpl(2, 2)
            + ' '
            + zpl(4, 2) + ':'
            + zpl(5, 2) + ':'
            + zpl(6, 2);
    };
    EduRequest.prototype.timezone_datetime2int = function (datetime) {
        return Math.floor(lib_date_1.datetime_sql2js(datetime).getTime() / 1000);
    };
    EduRequest.prototype.maindbi = function (year, options) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var dbi, frontend;
            var _this = this;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4, Promise.resolve().then(function () { return require("../rpr/dbi"); })];
                    case 1: return [4, (_a.sent()).ClientDBI.newInstance(this, function (args) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                            return tslib_1.__generator(this, function (_a) {
                                switch (_a.label) {
                                    case 0: return [4, Promise.resolve().then(function () { return require("../rpr/server/maindbi"); })];
                                    case 1: return [2, (_a.sent()).mainDBIAccessor(null, year, {
                                            vt_filter: options.vt_filter,
                                            date: options.date
                                        }, args)];
                                }
                            });
                        }); }, options)];
                    case 2:
                        dbi = _a.sent();
                        frontend = {
                            showItemDlg: function (table, id) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                                return tslib_1.__generator(this, function (_a) {
                                    switch (_a.label) {
                                        case 0: return [4, Promise.resolve().then(function () { return require('../rpr/maindbi_ui'); })];
                                        case 1:
                                            (_a.sent()).showMainDbiItemDlg(year, table, id);
                                            return [2];
                                    }
                                });
                            }); },
                            showRemoveDlg: function (table, ids) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                                return tslib_1.__generator(this, function (_a) {
                                    switch (_a.label) {
                                        case 0:
                                            if (!(ids.length == 1)) return [3, 2];
                                            return [4, Promise.resolve().then(function () { return require('../rpr/maindbi_ui'); })];
                                        case 1:
                                            (_a.sent()).showMainDbiRemoveDlg(year, table, ids[0]);
                                            return [3, 3];
                                        case 2:
                                            ASC.dieError('5154220885');
                                            _a.label = 3;
                                        case 3: return [2];
                                    }
                                });
                            }); },
                            showVyberDlg: function (table, ids) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                                return tslib_1.__generator(this, function (_a) {
                                    switch (_a.label) {
                                        case 0: return [4, Promise.resolve().then(function () { return require('../rpr/vyber'); })];
                                        case 1: return [2, (_a.sent()).showDBIVyberDlg(dbi, table, ids)];
                                    }
                                });
                            }); }
                        };
                        dbi.frontend = frontend;
                        return [2, dbi];
                }
            });
        });
    };
    EduRequest.prototype.substdbi = function (dbid, options) {
        if (options === void 0) { options = {}; }
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var _this = this;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4, Promise.resolve().then(function () { return require("../rpr/dbi"); })];
                    case 1: return [2, (_a.sent()).ClientDBI.newInstance(this, function (args) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                            return tslib_1.__generator(this, function (_a) {
                                switch (_a.label) {
                                    case 0: return [4, Promise.resolve().then(function () { return require("../substitution/server/substdbi"); })];
                                    case 1: return [2, (_a.sent()).substDBIAccessor(null, dbid, args)];
                                }
                            });
                        }); }, options)];
                }
            });
        });
    };
    EduRequest.prototype.timetabledbi = function (num, options) {
        if (options === void 0) { options = {}; }
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var _this = this;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4, Promise.resolve().then(function () { return require("../rpr/dbi"); })];
                    case 1: return [2, (_a.sent()).ClientDBI.newInstance(this, function (args) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                            return tslib_1.__generator(this, function (_a) {
                                switch (_a.label) {
                                    case 0: return [4, Promise.resolve().then(function () { return require("../timetable/server/ttdbi"); })];
                                    case 1: return [2, (_a.sent()).timetableDBIAccessor(null, num, args)];
                                }
                            });
                        }); }, options)];
                }
            });
        });
    };
    EduRequest.prototype.ttuidocdbi = function (ttgpid, options) {
        if (options === void 0) { options = {}; }
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var dbi, frontend;
            var _this = this;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4, Promise.resolve().then(function () { return require("../rpr/dbi"); })];
                    case 1: return [4, (_a.sent()).ClientDBI.newInstance(this, function (args) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                            return tslib_1.__generator(this, function (_a) {
                                switch (_a.label) {
                                    case 0: return [4, Promise.resolve().then(function () { return require("../timetable/app/server/ttdoc"); })];
                                    case 1: return [2, (_a.sent()).ttuidocDBIAccessor(null, ttgpid, args)];
                                }
                            });
                        }); }, options)];
                    case 2:
                        dbi = _a.sent();
                        frontend = {
                            showItemDlg: function (table, id) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                                return tslib_1.__generator(this, function (_a) {
                                    switch (_a.label) {
                                        case 0: return [4, Promise.resolve().then(function () { return require('../timetable/app/dlg'); })];
                                        case 1: return [2, (_a.sent()).showItemDlg(ttgpid, table, id)];
                                    }
                                });
                            }); },
                            showRemoveDlg: function (table, ids) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                                return tslib_1.__generator(this, function (_a) {
                                    switch (_a.label) {
                                        case 0: return [4, Promise.resolve().then(function () { return require('../timetable/app/dlg'); })];
                                        case 1: return [2, (_a.sent()).showRemoveDlg(ttgpid, table, ids)];
                                    }
                                });
                            }); },
                            showVyberDlg: function (table, ids) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                                return tslib_1.__generator(this, function (_a) {
                                    switch (_a.label) {
                                        case 0: return [4, Promise.resolve().then(function () { return require('../timetable/app/ttdoc'); })];
                                        case 1: return [2, (_a.sent()).showTTDocVyberDlg(dbi, table, ids)];
                                    }
                                });
                            }); }
                        };
                        dbi.frontend = frontend;
                        return [2, dbi];
                }
            });
        });
    };
    EduRequest.prototype.memoize = function (key, supplier) {
        var vp = this._memoize_cache.get(key);
        if (!vp) {
            vp = supplier();
            this._memoize_cache.set(key, vp);
        }
        return vp;
    };
    return EduRequest;
}());
exports.EduRequest = EduRequest;
var EduRequest_Client = (function (_super) {
    tslib_1.__extends(EduRequest_Client, _super);
    function EduRequest_Client() {
        var _a;
        var _this = _super.call(this) || this;
        _this.lib_date = new lib_date_1.Lib_date(_this);
        var req_props = ASC.req_props;
        _super.prototype.initRequest.call(_this, req_props || {});
        if (!req_props) {
            if (window && !((_a = window.MobileAppBridge) === null || _a === void 0 ? void 0 : _a.isActive()))
                ASC.sendErrorJS('9883465806', [
                    ASC.edupage,
                    ASC.school_country,
                    new Error().stack,
                ].join('|'));
        }
        return _this;
    }
    return EduRequest_Client;
}(EduRequest));
exports.EduRequest_Client = EduRequest_Client;
exports.client_req = new EduRequest_Client();
exports['req'] = exports.client_req;
ASC.req = exports.client_req;
