"use strict";
exports.__esModule = true;
var tslib_1 = require("tslib");
var React = require("react");
var report_1 = require("./online/report");
var lib_date_1 = require("../asc/lib_date");
var asc_react_1 = require("../asc/asc_react");
var viewer_1 = require("./server/viewer");
exports.substViewerModeName = {
    teachers: '{1929}',
    classes: '{1930}',
    me: '{9092}',
    admin: 'Information for admin'
};
var substViewerModeName_small = {
    teachers: '{1005}',
    classes: '{1194}',
    me: '{1751}',
    admin: 'Admin'
};
function SubstViewer(props) {
    var _this = this;
    var _a = React.useState(props.date), date = _a[0], setDate = _a[1];
    var _b = React.useState(props.mode), mode = _b[0], setMode = _b[1];
    var first = React.useRef(true);
    var rl = asc_react_1.useResponsiveLevel();
    var req = asc_react_1.useReq();
    var report_html = asc_react_1.useAsyncMemo(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    if (first.current) {
                        first.current = false;
                        return [2, props.report_html];
                    }
                    return [4, viewer_1.getSubstViewerDayDataHtml(null, { date: date, mode: mode })];
                case 1: return [2, _a.sent()];
            }
        });
    }); }, [date, mode, props.refresh], function () { return first.current ? props.report_html : ''; }, { inputs_reset: [date, mode, props.refresh] });
    var DSW = rl > 0 ? MobileDateSwitcher : DateSwitcher;
    var swipe = useSwipe({
        onHoziontalSwipe: function (dir) {
            var target_date = dirDate(req, date, dir, props);
            if (target_date)
                setDate(target_date);
        }
    });
    var date_limitfrom = props.date_limitfrom, enabled_modes = props.enabled_modes;
    return React.createElement("div", tslib_1.__assign({}, swipe, { className: props.mobile ? 'app-view-fullHeight' : '', style: { backgroundColor: '#ffffff', color: '#000000', padding: 5 } }),
        React.createElement(DSW, tslib_1.__assign({}, {
            date_limitfrom: date_limitfrom,
            date: date,
            onDate: function (date) { return setDate(date); }
        })),
        React.createElement(asc_react_1.VGap, { height: 20 }),
        enabled_modes.length > 0
            ? React.createElement(React.Fragment, null,
                React.createElement(report_1.SubstReportTitle, { title: rl > 0
                        ? undefined
                        : req.ls(1003) + ' - ' + lib_date_1.date_format_day(req, date, true, true), subtitle: enabled_modes.map(function (em) {
                        var selected = mode == em;
                        return React.createElement(ViewerMode, tslib_1.__assign({}, {
                            req: req,
                            key: em,
                            mode: em,
                            selected: selected,
                            onClick: selected ? undefined : function () {
                                setMode(em);
                            }
                        }));
                    }) }),
                report_html
                    ? React.createElement("div", { dangerouslySetInnerHTML: { __html: report_html } })
                    : React.createElement(asc_react_1.Loading, null))
            : React.createElement("div", { style: { textAlign: 'center' } }, req.ls(2854)));
}
exports.SubstViewer = SubstViewer;
function ViewerMode(props) {
    var mode = props.mode, selected = props.selected, onClick = props.onClick;
    var req = asc_react_1.useReq();
    var _a = asc_react_1.useHover(), isHovering = _a[0], hoverProps = _a[1];
    var rl = asc_react_1.useResponsiveLevel();
    return React.createElement("span", tslib_1.__assign({}, hoverProps, { style: {
            color: selected ? '#000000' : '#A0A0A0',
            marginLeft: 10,
            cursor: onClick ? 'pointer' : undefined,
            backgroundColor: (isHovering || selected) ? '#e8e8e8' : undefined,
            padding: rl > 0 ? 5 : undefined
        }, onClick: onClick }), req.localize((rl > 0 ? substViewerModeName_small : exports.substViewerModeName)[mode]));
}
function DateSwitcher(props) {
    var req = asc_react_1.useReq();
    var rl = asc_react_1.useResponsiveLevel();
    var small = rl > 0;
    var colors = asc_react_1.useColors();
    var _a = React.useState(function () {
        if (small)
            return props.date;
        var week_from = lib_date_1.date_week(req, lib_date_1.date_delta(props.date, -7));
        var datefrom = lib_date_1.week_start(req, week_from);
        if (props.date_limitfrom && props.date_limitfrom > datefrom)
            datefrom = props.date_limitfrom;
        return datefrom;
    }), datefrom = _a[0], setDatefrom = _a[1];
    var _b = React.useState(false), isClient = _b[0], setIsClient = _b[1];
    React.useEffect(function () { return setIsClient(true); });
    var date_limitfrom = props.date_limitfrom;
    var dateto = lib_date_1.date_delta(datefrom, small ? 6 : +18);
    var dates = lib_date_1.date_interval_array(datefrom, dateto);
    var scrollers = [-1, 1].map(function (dir) { return React.createElement("div", { className: 'scroller', onMouseDown: function (e) { return e.preventDefault(); }, style: {}, onClick: function (e) {
            if (dir < 0 && datefrom == date_limitfrom)
                return;
            setDatefrom(lib_date_1.date_delta(datefrom, dir));
        } }, dir < 0 ? '<' : '>'); });
    var cell_minWidth = small
        ? 35
        : Math.floor((738 - 2 * (15 + 2) - (dates.length) * 1) / dates.length);
    return React.createElement(asc_react_1.RScopedStyle, { className: 'SubstViewDateSwitcher', rules: {
            '.switcher': {
                display: 'flex',
                flexDirection: 'row',
                flex: 1
            },
            '.cell': {
                whiteSpace: 'pre',
                textAlign: 'center',
                flex: '1 1 0px',
                minWidth: cell_minWidth,
                width: cell_minWidth,
                flexBasis: cell_minWidth,
                color: colors.fgGrey,
                cursor: 'pointer',
                marginRight: 1,
                transition: 'opacity 0.1s'
            },
            '.cell::first-line': {
                fontSize: 15,
                fontWeight: 'bold'
            },
            '.cell:hover': {
                backgroundColor: colors.bgHover
            },
            '.cell.weekend': {
                color: '#d0d0d0'
            },
            '.cell.selected': {
                backgroundColor: colors.bgHover,
                color: colors.fgBlack,
                cursor: 'auto',
                opacity: 1
            },
            '.cell.filler': {
                visibility: 'hidden',
                height: 0,
                display: 'none'
            },
            '.scroller': {
                paddingTop: 7,
                cursor: 'pointer',
                minWidth: small ? 25 : 30,
                width: 30,
                flex: '0 0 auto',
                textAlign: 'center',
                color: '#808080',
                visibility: small ? undefined : 'hidden'
            },
            '.scroller:hover': {
                backgroundColor: '#e8e8e8'
            },
            '$:hover .scroller': {
                visibility: 'visible'
            }
        }, style: {
            display: 'flex',
            flexDirection: 'row',
            fontSize: 11,
            flex: 'none'
        } },
        scrollers[0],
        React.createElement("div", { className: 'switcher' },
            dates.map(function (date) {
                var weekend = lib_date_1.date_isWeekend(req, date);
                var day = lib_date_1.date_format_day(req, date, false, 'short');
                var i = day.indexOf(' ');
                if (i >= 0)
                    day = day.substr(0, i) + "\n" + day.substr(i + 1);
                day = day.replace(/ /g, '');
                var selected = date == props.date;
                return React.createElement("div", { key: date, className: asc_react_1.classNames({ cell: true, selected: selected, weekend: weekend }), style: tslib_1.__assign({}, (isClient || selected)
                        ? {}
                        : {
                            opacity: 0.5,
                            pointerEvents: 'none',
                            cursor: 'auto'
                        }), onClick: selected ? undefined : function () { return props.onDate(date); } }, day);
            }),
            asc_react_1.rangeFromTo(1, 21).map(function (i) { return React.createElement("div", { key: '' + i, className: 'cell filler' }); })),
        scrollers[1]);
}
exports.DateSwitcher = DateSwitcher;
function dirDate(req, date, dir, params) {
    var allowWeekend = false;
    var target_date = lib_date_1.date_delta(date, dir);
    for (var i = 0; i < 3; i++) {
        if (allowWeekend || !lib_date_1.date_isWeekend(req, target_date))
            break;
        target_date = lib_date_1.date_delta(target_date, dir);
    }
    if (target_date < params.date_limitfrom)
        return '';
    return target_date;
}
function MobileDateSwitcher(props) {
    var date = props.date;
    var req = asc_react_1.useReq();
    function sipka(dir) {
        var target_date = dirDate(req, date, dir, props);
        var enabled = !!target_date;
        return React.createElement("div", { onClick: function () { return enabled && props.onDate(target_date); }, style: {
                cursor: 'pointer',
                padding: '0px 10px',
                color: enabled ? undefined : '#c0c0c0'
            }, onMouseDown: function (e) { return e.preventDefault(); } }, dir < 0 ? '<' : '>');
    }
    return React.createElement("div", { style: {
            fontSize: 20,
            display: 'flex',
            flexDirection: 'row'
        } },
        sipka(-1),
        React.createElement("div", { style: {
                textAlign: 'center',
                flex: '1 1 0px'
            } }, lib_date_1.date_format_day(req, date, true, true)),
        sipka(1));
}
function useSwipe(params) {
    var startEventRef = React.useRef();
    return {
        onTouchStart: function (e) {
            e.persist();
            startEventRef.current = e;
        },
        onTouchEnd: function (e2) {
            var e1 = startEventRef.current;
            var t1 = e1.changedTouches[0];
            var t2 = e2.changedTouches[0];
            if (params.onHoziontalSwipe) {
                var dist = t1.pageX - t2.pageX;
                var elapsedTime = e2.timeStamp - e1.timeStamp;
                if (elapsedTime < 300 && Math.abs(dist) > 80) {
                    params.onHoziontalSwipe(dist < 0 ? -1 : 1, e2);
                }
            }
        }
    };
}
